@@ -655,4 +655,4 @@ julia> wf[0.9..1.5]
 ```
 
 """
-function (..) end
\ No newline at end of file
+..
